## Citing Academy

If you use Academy in your work, please cite our preprint: [**Empowering Scientific Workflows with Federated Agents**](https://arxiv.org/abs/2505.05428).

> Pauloski, J. Gregory, Yadu Babuji, Ryan Chard, Mansi Sakarvadia, Kyle Chard, and Ian Foster. "Empowering Scientific Workflows with Federated Agents." arXiv preprint arXiv:2505.05428 (2025).

```bib
@misc{pauloski2025academy,
    title = {Empowering {S}cientific {W}orkflows with {F}ederated {A}gents},
    author = {J. Gregory Pauloski and Yadu Babuji and Ryan Chard and Mansi Sakarvadia and Kyle Chard and Ian Foster},
    archiveprefix = {arXiv},
    eprint = {2505.05428},
    primaryclass = {cs.MA},
    url = {https://arxiv.org/abs/2505.05428},
    year = {2025}
}
```

## Featured Publications

!!! note

    Check back later.
